@@ -1,7 +1,7 @@
 def app(environ, start_response):
-    data = 'OK\n'
+    data = b'OK\n'
     response_headers = [
-        ('Content-type','text/plain'),
+        ('Content-type', 'text/plain'),
         ('Content-Length', str(len(data)))
     ]
     start_response('200 OK', response_headers)
